@@ -89,8 +89,13 @@ _UNITS.add_group(
 
 _UNITS.add_group(
     group_name="pressure",
-    units=[Unit("pa", synonyms=["pascal"], is_si_unit=True), Unit("psi")],
-    converters=[Converter("psi", "pa", lambda psi: psi * 6894.76), Converter("pa", "psi", lambda pa: pa / 6894.76)],
+    units=[Unit("pa", synonyms=["pascal"], is_si_unit=True), Unit("psi"), Unit("bar")],
+    converters=[
+        Converter("psi", "pa", lambda psi: psi * 6894.76),
+        Converter("pa", "psi", lambda pa: pa / 6894.76),
+        Converter("bar", "pa", lambda bar: bar * 100000),
+        Converter("pa", "bar", lambda bar: bar / 100000),
+    ],
 )
 
 
@@ -121,6 +126,8 @@ _UNITS.add_group(
         Converter("usgpm", "m3s", lambda usgpm: usgpm / 15850),
         Converter("usgpd", "m3s", lambda usgpd: usgpd / (15850 * 1440)),
         Converter("bpd", "m3s", lambda bpd: bpd * 0.0000018401307),
+        Converter("usgpm", "bpd", lambda usgpm: usgpm * 34.29),
+        Converter("bpd", "usgpm", lambda bpd: bpd / 34.29),
     ],
 )
 
